/*
 * RemoteTableDemo.java
 * 
 * Originally written by Joseph Bowbeer and released into the public domain.
 * This may be used for any purposes whatsoever without acknowledgment.
 */

package jozart.remotetabledemo;

import java.awt.event.*;
import javax.swing.*;
import javax.swing.table.*;

import jozart.remotetable.*;

/**
 * Demos a remote editor, remote viewer, and remote table model
 * together in one applet. 
 *
 * @author  Joseph Bowbeer
 * @version 1.0
 */
public class RemoteTableDemo extends javax.swing.JApplet {

// Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
// End of variables declaration//GEN-END:variables

    private RemoteTableEditor editor;
    private RemoteTableViewer viewer;

    /** Initializes the Form */
    public RemoteTableDemo() {
        initComponents ();

        try {

            /* Create remote table model. */
            TableModel model = RemoteTableServer.createLocalModel();
            final RemoteTableModel adapter =
                new RemoteTableModelAdapter(model);

            /* Create an editor linked to the remote model. */
            editor = new RemoteTableEditor() {
                protected RemoteTableModel lookupRemoteModel() {
                    return adapter;
                }
            };

            /* Create a viewer linked to the remote model. */
            viewer = new RemoteTableViewer() {
                protected RemoteTableModel lookupRemoteModel() {
                    return adapter;
                }
            };

            jPanel1.add(editor, "Center");
            jPanel2.add(viewer, "Center");

        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    /**
     * Called from within the constructor to initialize the form.
     * The content of this method is generated by NetBeans.
     */
    private void initComponents () {//GEN-BEGIN:initComponents
        getContentPane ().setLayout (new java.awt.GridLayout (2, 1));

        jPanel1 = new javax.swing.JPanel ();
        jPanel1.setBorder (new javax.swing.border.CompoundBorder (
            new javax.swing.border.EmptyBorder (new java.awt.Insets(10, 4, 4, 4)),
            new javax.swing.border.TitledBorder (
            new javax.swing.border.EtchedBorder (), "Editor", 1, 2,
            new java.awt.Font ("Dialog", 1, 14))));
        jPanel1.setLayout (new java.awt.BorderLayout ());

        getContentPane ().add (jPanel1);

        jPanel2 = new javax.swing.JPanel ();
        jPanel2.setBorder (new javax.swing.border.CompoundBorder (
            new javax.swing.border.EmptyBorder (new java.awt.Insets(10, 4, 4, 4)),
            new javax.swing.border.TitledBorder (
            new javax.swing.border.EtchedBorder (), "Viewer", 1, 2,
            new java.awt.Font ("Dialog", 1, 14))));
        jPanel2.setLayout (new java.awt.BorderLayout ());

        getContentPane ().add (jPanel2);

    }//GEN-END:initComponents

    public void start() {
        editor.start();
        viewer.start();
    }

    public void stop() {
        editor.stop();
        viewer.stop();
    }

    public void shutdown(int timeout) {
        editor.shutdown(timeout);
        viewer.shutdown(timeout);
    }

    /**
     * Launches this applet in a frame.
     */
    public static void main(String[] args) {

        JFrame frame = new JFrame("Remote Table Demo");
        final RemoteTableDemo applet = new RemoteTableDemo();
        frame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent event) {
                applet.shutdown(1000);
                System.exit(0);
            }
        });
        frame.getContentPane().add(applet, "Center");
        frame.pack();
        frame.show();
        applet.init();
        applet.start();
    }

}
